# IBM Qiskit Code Assistant (Beta) Software End User License Agreement

**PLEASE READ CAREFULLY** This IBM Qiskit Code Assistant (Beta) Software End User License Agreement ("EULA") is between the individual end user receiving and utilizing software and the associated cloud service under this EULA (“You”) and International Business Machines Corporation, a New York Corporation ("IBM"), and consists of (a) the terms of this EULA, and (b) the IBM Privacy Policies (defined below) (collectively, this “Agreement”). You and IBM may be referred to herein individually as a “Party”, or collectively as the “Parties.”

By clicking to accept this Agreement via an IBM webpage or by otherwise accepting this Agreement, You (i) accept the terms of this Agreement, as may be amended from time to time at IBM's sole discretion, and (ii) understand that You are entering a binding legal agreement.

1. General.

   a. This Agreement and Your license (described below) governs Your use of the IBM software program (the "Program") that permits and facilitates delivery and use of associated IBM service, collectively referred to as IBM Qiskit Code Assistant (Beta) (collectively, the “Service”) as further set forth herein. The Service is a ”beta” service intended to help users leverage generative AI to write code using Qiskit, is of an experimental/exploratory nature, and is provided solely for research, education, evaluation, testing and feedback purposes (the “Authorized Use”). IBM will provide You with a copy of the Program in object code format only, and use of the Service including the Program is only for the Authorized Use.

   b. You may withdraw from this EULA at any time by deleting the Program and ceasing to use the Service.

   c. IBM may withdraw or make changes to the Service, including the Program, at any time at IBM's sole discretion. IBM may change the terms of this Agreement at any time. If You do not agree to the updated terms, please do not further utilize the Service.

   d. **BY DOWNLOADING, INSTALLING, COPYING, ACCESSING, CLICKING ON AN "ACCEPT" BUTTON, OR OTHERWISE USING THE SERVICE, YOU AGREE TO THE TERMS OF THIS AGREEMENT. IF YOU ARE ACCEPTING THESE TERMS ON BEHALF OF ANOTHER LICENSEE, YOU REPRESENT THAT YOU HAVE FULL AUTHORITY TO BIND LICENSEE TO THESE TERMS.**

   e. **IF YOU ARE USING THE SERVICE FOR CRAFTING CODE FOR EXECUTION WITH OTHER IBM QUANTUM COMPUTING SERVICES, INCLUDING PAID ACCESS (PAID FOR BY YOUR EMPLOYER OR OTHER ENTITY) TO IBM QUANTUM COMPUTING SERVICES THAT PROVIDE FOR EXECUTION OF QUANTUM CIRCUITS ON IBM QUANTUM SYSTEMS, YOU REPRESENT THAT YOU HAVE AUTHORIZATION AND PERMISSION FROM YOUR EMPLOYER OR OTHER ENTITY TO USE THIS SERVICE IN CONJUNCTION THEREWITH.**

   f. **IF YOU DO NOT AGREE TO THESE TERMS OR DO NOT HAVE AUTHORITY: i) DO NOT DOWNLOAD, INSTALL, COPY, ACCESS, CLICK ON AN "ACCEPT" BUTTON, OR USE THE PROGRAM; AND ii) PROMPTLY RETURN THE UNUSED MEDIA, DOCUMENTATION, AND PROOF OF ENTITLEMENT TO THE PARTY FROM WHOM IT WAS OBTAINED FOR A REFUND OF THE AMOUNT PAID, IF ANY. IF THE PROGRAM WAS DOWNLOADED, DESTROY ALL COPIES OF THE PROGRAM.**

2. Licenses.

   g. The Service, including the Program, is owned by IBM, including all rights, title and interest.

   h. All intellectual property rights and title to pre-existing materials are unaﬀected by this Agreement.

   i. You own Your original scripts created by You that You enter into the Service.

   j. For the term of this Agreement, IBM grants You a limited, nonexclusive, nontransferable license to access and use the Service for research, education, testing, evaluation and feedback purposes (Authorized Use), all provided that You:

   I. reproduce all intellectual property notices and other legends of ownership on each copy, or partial copy, of any IBM information downloaded from any associated IBM websites;

   II. do not use the Service for commercial purposes;
   III. do not distribute or redistribute the Program to anyone (it is only for your personal Authorized Use); and
   IV. remain in compliance with all terms and conditions of this Agreement.

   k. You may choose to provide feedback to IBM at your option. If you do provide feedback to IBM, you grant to IBM a perpetual, fully paid up, irrevocable, nonexclusive, worldwide license to such feedback to use, execute, display, reproduce, make, perform, disclose, prepare derivative works from, and distribute, sell and transmit (internally and externally) such feedback and derivative works therefrom for any purpose. This includes the right of IBM to sublicense these rights to any third-party without consent or accounting by IBM to You. You represent that any feedback provided to IBM is original and that no part of such feedback violates any intellectual property rights of any third party.

   l. Excluding any IBM logos or trademarks, IBM gives you permission to use (limited to the Authorized Use) results generated through your use of the Service, including those displayed on IBM applications, including by screen capture, provided that You cite the source as “created using IBM Qiskit Code Assistant”.

   m. You grant the rights and permissions to IBM, its aﬃliates, and contractors of either, to use, provide, store, and otherwise process Content solely for the purpose of providing operation of the Service.

   n. You are responsible for obtaining all necessary rights and permissions to permit processing of Content by the Service.

   o. You may not provide, authorize access, or input personal or other regulated data for processing by the Service.

   p. If any Content could be subject to governmental regulation or may require security measures beyond those speciﬁed by IBM for the Program, You will not provide, allow access to, or input the Content for processing by the Service unless IBM has ﬁrst agreed in writing to implement additional security and other measures. You are solely responsible for adequate back-up of Content provided as input to the Program and back-up of any Results generated by the Program.

   q. You are responsible for selecting, ordering, enabling, and using available data protection features appropriate to support Your use of the Service.

   r. You are responsible for assessing the suitability of the Service for the Content and Your Authorized Use of Content with the Service. You acknowledge that the use of the Service meets Your requirements for the Authorized Use and processing instructions required to comply with applicable laws.

3. Conﬁdentiality.

   a. Both Parties agree that all information exchanged under this Agreement is non-conﬁdential. If either Party requires the exchange of conﬁdential information, it will be made under a separate signed conﬁdentiality agreement

4. No Warranties.

   Subject to any statutory warranties which cannot be excluded and may apply to You (such warranties are limited in duration to the minimum period permitted under applicable law), The Service is provided AS IS and IBM makes no warranties, express or implied, regarding The Service, or support thereof, including, but not limited to, any implied warranties or conditions of merchantability, satisfactory quality, ﬁtness for a particular purpose, and title, and any warranty or condition of non-infringement. Results are not guaranteed and IBM makes no representation on the availability of The Service and any associated services.

5. Limitation of Liability.

   5.1 Items for Which IBM May Be Liable. IBM’s entire liability for all claims in the aggregate arising from or related to this Agreement or any harm or otherwise arising under this Agreement will not exceed the amount of any (1) damages for bodily injury (including death) and damage to real property and tangible personal property, (2) other actual direct damages up to U.S. $10,000 (or equivalent in local currency), and (3) damages that cannot be limited under applicable law. This limit also applies collectively to IBM, its aﬃliates, contractors, and suppliers, and is the maximum for which they are collectively responsible.

   5.2 Items for Which IBM Is Not Liable. Under no circumstances will IBM, even if informed about the possibility of the following, be liable for: special, incidental, exemplary, indirect, or economic consequential damages; lost proﬁts, business value, revenue, goodwill, or anticipated savings; or loss of or damage to data.

   The disclaimers and exclusions in this Agreement also apply to IBM's aﬃliates, contractors, and suppliers. Providers of non-IBM products and services may provide their own warranties. IBM has no responsibility for claims based on non-IBM products and services, or any violation of law or third-party rights caused by Your Content.

6. Personal Data

   a. This beta Service is available on a trial basis, may have certain features disabled, and is not designed to comply with any specific governmental regulation or specific security measures. You agree that no Content that includes personal data will be provided to IBM in connection with your use of the Service, including such that may be subject to European General Protection Regulations (GDPR) requirements.

   b. IBM, its aﬃliates, and contractors of either, may, wherever they do business, store and otherwise process Your personal identiﬁable information (PII), as detailed in the IBM Privacy Statement and the IBM Quantum Privacy Page), for the purposes and the duration as set forth in the IBM Privacy Statement and the IBM Quantum Privacy Page.

   The IBM Privacy Policies provide additional details. By accepting this Agreement, You are giving IBM Your consent to collect, access, store and use the PII speciﬁed in this Article 6, all in accordance with this Agreement (including the IBM Privacy Policies).

   c. You may withdraw consent at any time by notifying IBM via Your IBM Quantum account page or as detailed in the IBM Privacy Policies.

   d. You represent that You will not provide IBM with any personally identiﬁable information that relates to or identiﬁes an individual, other than the PII speciﬁed in this Article 6.

7. Service Levels and Technical Support

   e. Service Level Agreement
   Service Level Agreements are not applicable for this preview Cloud Service.

   f. Technical Support
   IBM uses commercially reasonable efforts to respond to support requests; however, there is no specified response time objective for support.

8. Client Use of Output

   Based on Your input, the Service will provide suggested tasks and other materials as generated outputs. Your inputs to the Service are Your Content. IBM does not claim to have ownership rights to any generated output. You are solely responsible for outputs generated by the Service, and You should exercise discretion and evaluate whether outputs generated from the model are appropriate for the Your environment. The generated outputs will likely require modifications by You. Unless separately authorized by You through a voluntary feedback submission, IBM will not use the Your Content or generated outputs to train the Service.

9. Changes

   IBM may in its reasonable discretion, change these terms, modify the computing environment, or withdraw the Cloud Service, in whole or in part by providing notice. Continued use is Client's acceptance of any such change. If Client does not accept a change, Client is responsible to terminate Client's use.

10. Preview Cloud Service

    IBM Qiskit Code Assistant is provided as a preview service. The Service may not be at a level of performance or compatibility of generally available services and is not fully tested. Such services are not designed for any type of Content that contains personal data or for use in a production environment. You are responsible to remove content You wish to retain prior to expiration or termination of the beta service. IBM provides access to the Service without warranties of any kind and is not liable for any damages arising out of Your use of the Service. IBM may change, discontinue, or suspend access to IBM Qiskit Code Assistant at any time and without notice.

    As a preview service, IBM does not commit to full implementation of the requirements included within the IBM Data Security and Privacy Principles for IBM Qiskit Code Assistant. All features, functions, and documentation for IBM Qiskit Code Assistant are to be treated “as-is” and secured in a commensurate manner during the preview of the products. As a preview feature, the use of IBM Qiskit Code Assistant is excluded from any service level agreements.

11. Miscellaneous

    a. IBM may terminate, suspend, revoke or limit Your access to The Service at IBM’s discretion.

    b. The Service may not be used for unlawful, obscene, oﬀensive or fraudulent activity, such as advocating or causing harm, interfering with or violating the integrity or security of a network or system, evading ﬁlters, sending unsolicited, abusive, deceptive or disparaging messages, viruses or harmful code, violating third party rights, for the research, design, development, production, maintenance, repair, overhaul, or use of any oﬀensive or defensive weapons of any kind, for attempting to defeat encryption, or for processing regulated data including personal information, ﬁnancial data and health data. In addition, IBM may remove or refuse to accept or use any Content without limitation.

    c. You may not reverse engineer or otherwise attempt to discover or decode any hardware component of The Service.

    d. You may not use The Service in any application or situation its use or failure could lead to death or serious bodily injury of any person, or to severe physical or environmental damage, such as aircraft, motor vehicles or mass transport, nuclear or chemical facilities, life support or medical equipment, or weaponry systems.

    e. Your account credentials are for Your use only. You are not permitted to share or otherwise provide access to other individuals using your account credentials. You are permitted to create a single set of account credentials for accessing the Service. Users creating more than one account are subject to having all IBM Quantum accounts associated with that user terminated.

    f. You will not use the Service in any way that harms IBM, IBM Quantum, other users of IBM services, or other computer systems, and intellectual property rights therein. You will promptly notify IBM if You discover or suspect that Content may harm IBM, the Service, or its users, and will fully cooperate with IBM’s eﬀorts to protect the Service and its users.

    g. You will not circumvent any restrictions placed on Your account, including employing practices to mask Your physical location.

    h. Each Party agrees to comply and reasonably assist the other in complying with applicable government export and import laws and regulations including those of the United States. You agree that You will not access the Service in a manner contrary to U.S. or other applicable export, embargo, and sanctions regulations, including restrictions related to certain end uses and end users. Further, both Parties will not directly or indirectly export or re-export, at any time, any technology, software and/or commodities furnished through this Agreement, or its direct product, to any prohibited country (including release of technology, software and/or commodities to nationals, wherever they may be located, of any prohibited country) as speciﬁed in applicable export, embargo, and sanctions regulations.

    i. You represent that Content will not, in whole or part, be (1) regulated data of any kind, including but not limited to sensitive healthcare or ﬁnancial data, (2) Content controlled under the U.S. International Traﬃc in Arms Regulation (ITAR) or the defense trade control regime of any country, (3) Content that requires an export license under applicable export control laws, or (4) Content described on the Commerce Control List of the U.S. Export Administration Regulations or the dual-use control list of any country.

    j. You acknowledge that IBM may use personnel in locations worldwide to support the delivery of the Service.

    k. Neither Party is responsible for failure to fulﬁll any obligations due to causes beyond its control.

    l. Except as explicitly provided in this Agreement, this Agreement does not grant any licenses, either directly or indirectly, by implication, estoppel or otherwise, to either Party under any patent, copyright or other intellectual property right of the other Party.

    m. This Agreement does not confer any right to use in advertising, publications or promotional activities, or otherwise, any IBM owned name, trade name, trademarks, logos, or other designations, including any contraction, abbreviation or simulation of any of the foregoing.

    n. You may not assign this Agreement, in whole or in part, without IBM's prior written consent. Any attempt to do so is void.

    o. Any terms of this Agreement that by their nature extend beyond termination of this Agreement remain in eﬀect until fulﬁlled, and apply to both Parties' respective successors and assignees.

    p. Neither Party is a legal representative nor legal agent or partner of the other, and this Agreement does not create a joint venture between the Parties. IBM may enter into similar agreements with others and independently develop, acquire and market materials, products and services that may be competitive with You or Your employer’s products or services.

    q. If any provision of this Agreement is held to be invalid or unenforceable, the remaining provisions of this Agreement remain in full force and eﬀect.

    r. Each Party will allow the other reasonable opportunity to comply before it claims that the other has not met its obligations under this Agreement. The Parties will attempt to resolve disputes or claims relating to this Agreement in good faith.

    s. Unless otherwise required by applicable law without the possibility of contractual waiver or limitation: (1) neither Party will bring a legal action, regardless of form, for any claim arising out of or related to this Agreement more than two years after the cause of action arose; and (2) upon the expiration of such time limit, any such claim and all respective rights related to the claim lapse.

    t. No right or cause of action for any third-party is created by this Agreement, nor is IBM responsible for any third-party claims against You, except as permitted in Article 5.1 “Items for Which IBM May Be Liable” above.

    u. This Agreement and all related claims shall be governed by the laws of the State of New York, U.S.A., without regard to its conﬂict and choice-of-law principles. You consent to the exclusive jurisdiction and venue of the U.S. federal or state courts in New York, U.S.A., to resolve disputes or claims related to this Agreement. The Parties expressly waive the right to trial by jury in any matter which arises under this Agreement. Nothing in this Agreement aﬀects statutory rights that cannot be waived or limited by contract. The United Nations Convention on Contracts for the International Sale of Goods does not apply to transactions under this Agreement.

    v. This Agreement is the complete agreement between the Parties regarding its subject matter and supersedes any prior oral or written communications or understandings between the Parties related to its subject matter.
